@@ -75,7 +75,7 @@ static unsigned  update_interval   = 5;
 static int       background        = 2;
 static light     backlight         = LIGHTOFF;
 static Bool      switch_authorized = True;
-static Bool      show_devs         = True;
+static Bool      show_devs         = False;
 static Partition *partitions       = NULL;
 static Partition *current          = NULL;
 
@@ -463,8 +463,8 @@ static void parse_arguments(int argc, char **argv) {
             dockapp_isbrokenwm = True;
         } else if (!strcmp(argv[i], "--no-blink") || !strcmp(argv[i], "-nb")) {
             switch_authorized = False;
-        } else if (!strcmp(argv[i], "--mount-point") || !strcmp(argv[i], "-m")) {
-            show_devs = False;
+        } else if (!strcmp(argv[i], "--device") || !strcmp(argv[i], "-n")) {
+            show_devs = True;
         } else if (!strcmp(argv[i], "--single") || !strcmp(argv[i], "-s")) {
             background = 1;
         } else if (!strcmp(argv[i], "--partition") || !strcmp(argv[i], "-p")) {
@@ -491,7 +491,7 @@ static void print_help(char *prog)
            "  -w,  --windowed                run the application in windowed mode\n"
            "  -bw, --broken-wm               activate broken window manager fix\n"
            "  -p,  --partition <device>      show informations for device (may be used more than once)\n"
-           "  -m, --mount-point              show mount point instead of device\n"
+           "  -n, --device                   show device instead of mount point\n"
            "  -s, --single                   show only one device at a time\n");
     /* OPTIONS SUPP :
            "  -nb, --no-blink                disable blinking\n");
